# PyQt6-3D - Python Bindings for the Qt 3D Framework

PyQt6-3D is a set of Python bindings for The Qt Company's Qt 3D framework.  The
bindings sit on top of PyQt6 and are implemented as six separate modules
corresponding to the different libraries that make up the framework.


## Author

PyQt6-3D is copyright (c) Riverbank Computing Limited.  Its homepage is
https://www.riverbankcomputing.com/software/pyqt3d/.

Support may be obtained from the PyQt mailing list at
https://www.riverbankcomputing.com/mailman/listinfo/pyqt/.


## License

PyQt6-3D is released under the GPL v3 license and under a commercial license
that allows for the development of proprietary applications.


## Documentation

The documentation for the latest release can be found
[here](https://www.riverbankcomputing.com/static/Docs/PyQt6/).


## Installation

The GPL version of PyQt6-3D can be installed from PyPI:

    pip install PyQt6-3D

`pip` will also build and install the bindings from the sdist package but Qt's
`qmake` tool must be on `PATH`.

The `sip-install` tool will also install the bindings from the sdist package
but will allow you to configure many aspects of the installation.
